@@ -17,6 +17,7 @@ import os
 import requests
 
 from kolla.cmd import build as build_cmd
+from kolla import exception
 from kolla.image import build
 from kolla.tests import base
 
@@ -152,7 +153,7 @@ class KollaWorkerTest(base.TestCase):
         self.images = [image, image_child]
 
     def test_supported_base_type(self):
-        rh_base = ['fedora', 'centos', 'oraclelinux', 'rhel']
+        rh_base = ['centos', 'oraclelinux', 'rhel']
         rh_type = ['source', 'binary', 'rdo', 'rhos']
         deb_base = ['ubuntu', 'debian']
         deb_type = ['source', 'binary']
@@ -170,7 +171,7 @@ class KollaWorkerTest(base.TestCase):
                 ['ubuntu', 'debian'], ['rdo', 'rhos']):
             self.conf.set_override('base', base_distro)
             self.conf.set_override('install_type', install_type)
-            self.assertRaises(build.KollaMismatchBaseTypeException,
+            self.assertRaises(exception.KollaMismatchBaseTypeException,
                               build.KollaWorker, self.conf)
 
     def test_build_image_list_adds_plugins(self):
@@ -188,11 +189,16 @@ class KollaWorkerTest(base.TestCase):
             'source': 'https://git.openstack.org/openstack/networking-arista',
             'type': 'git'
         }
+
+        found = False
         for image in kolla.images:
             if image.name == 'neutron-server':
-                self.assertEqual(image.plugins[0], expected_plugin)
+                for plugin in image.plugins:
+                    if plugin == expected_plugin:
+                        found = True
+                        break
                 break
-        else:
+        if not found:
             self.fail('Can not find the expected neutron arista plugin')
 
     def test_build_image_list_plugin_parsing(self):
@@ -224,6 +230,12 @@ class KollaWorkerTest(base.TestCase):
 
         self.assertEqual(2, len(self._get_matched_images(kolla.images)))
 
+    def test_build_rpm_setup(self):
+        """checking the length of list of docker commands"""
+        self.conf.set_override('rpm_setup_config', ["a.rpm", "b.repo"])
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual(2, len(kolla.rpm_setup))
+
     def test_pre_defined_exist_profile(self):
         # default profile include the fake image: image-base
         self.conf.set_override('profile', ['default'])
